@@ -56,7 +56,8 @@ class EngineDiscoverer(GObject.GObject):
         self.jsonpath = addUserConfigPrefix("engines.json")
         self.engines = []
         try:
-            self.engines = json.load(open(self.jsonpath))
+            with open(self.jsonpath) as fh:
+                self.engines = json.load(fh)
         except ValueError as err:
             log.warning(
                 "engineNest: Couldn\'t read engines.json, renamed it to .bak\n%s\n%s"
@@ -443,12 +444,14 @@ class EngineDiscoverer(GObject.GObject):
         for engine in ENGINES_LIST:
             if engine.name.lower() in name.lower():
                 # Properties of the engine
-                result = {"name": name,
+                result = {"name": os.path.basename(name),
                           "protocol": engine.protocol[:6],
                           "recheck": True,
                           "country": engine.country,
                           "comment": "",
                           "level": ENGINE_DEFAULT_LEVEL if engine.defaultLevel is None else engine.defaultLevel}
+                if '/' in name or '\\' in name:
+                    result["command"] = name
                 if engine.protocol == "xboard1":
                     result["protover"] = 1
                 if engine.protocol == "xboard2":
@@ -592,6 +595,10 @@ class EngineDiscoverer(GObject.GObject):
             engine["vm_args"] = vm_args
         self.engines.append(engine)
 
+    def addEngineFromReference(self, engine):
+        if engine is not None:
+            self.engines.append(engine)
+
     def removeEngine(self, name):
         names = [engine["name"] for engine in self.engines]
         index = names.index(name)
