@@ -1,7 +1,10 @@
-from pychess.compat import cmp
 from pychess.Utils.const import ACTIONS
 
 
+def cmp(x, y):
+    return (x > y) - (x < y)
+
+
 class Offer:
     def __init__(self, type_, param=None, index=None):
         assert type_ in ACTIONS, "Offer.__init__(): type not in ACTIONS: %s" % repr(
