@@ -11,7 +11,7 @@ from .Move import Move
 from .const import LOSERSCHESS, WHITE, WHITEWON, BLACKWON, WON_NOMATERIAL, KING, HORDECHESS, \
     SUICIDECHESS, GIVEAWAYCHESS, ATOMICCHESS, WON_KINGEXPLODE, KINGOFTHEHILLCHESS, BLACK, DRAW, \
     CRAZYHOUSECHESS, WON_KINGINCENTER, THREECHECKCHESS, WON_THREECHECK, WON_MATE, DRAW_STALEMATE, \
-    DRAW_INSUFFICIENT, DRAW_EQUALMATERIAL, WON_LESSMATERIAL, WON_WIPEOUT, DRAW_REPITITION, \
+    DRAW_INSUFFICIENT, DRAW_EQUALMATERIAL, WON_LESSMATERIAL, WON_WIPEOUT, DRAW_REPETITION, \
     WON_KINGINEIGHTROW, RACINGKINGSCHESS, DRAW_50MOVES, DRAW_KINGSINEIGHTROW, RUNNING, ENPASSANT, UNKNOWN_REASON
 
 from .lutils.bitboard import iterBits
@@ -167,7 +167,7 @@ def getStatus(board):
                 return DRAW, DRAW_STALEMATE
 
     if lboard.repetitionCount() >= 3:
-        return DRAW, DRAW_REPITITION
+        return DRAW, DRAW_REPETITION
 
     if ldraw.testFifty(lboard):
         return DRAW, DRAW_50MOVES
