@@ -127,6 +127,10 @@ class LBoard:
 
         self.friends = [0, 0]
         self.kings = [-1, -1]
+
+        # this variable is a 2-dimmensionnal array, each case containing a bitboard
+        # self.boards[color] contains an array of bitboards, each representing the position of the pieces
+        # use example : self.boards[color][KNIGHT]
         self.boards = ([0] * 7, [0] * 7)
 
         self.enpassant = None  # cord which can be captured by enpassant or None
@@ -242,7 +246,7 @@ class LBoard:
         promoted = False
         # if there is a holding within [] we change it to BFEN style first
         if pieceChrs.endswith("]"):
-            pieceChrs = pieceChrs[:-1].replace("[", "/")
+            pieceChrs = pieceChrs[:-1].replace("[", "/").replace("-", "")
         for r, rank in enumerate(pieceChrs.split("/")):
             cord = (7 - r) * 8
             for char in rank:
