@@ -9,7 +9,7 @@ from .const import ADJOURNED_LOST_CONNECTION_BLACK, UNKNOWN_REASON, WON_LESSMATE
     ADJOURNED_LOST_CONNECTION, WON_NOMATERIAL, ADJOURNED, WON_DISCONNECTION, ABORTED, \
     ADJOURNED_AGREEMENT, WON_KINGEXPLODE, WON_KINGINCENTER, ABORTED_SERVER_SHUTDOWN, \
     ABORTED_AGREEMENT, WHITE_ENGINE_DIED, BLACK_ENGINE_DIED, WON_ADJUDICATION, \
-    ADJOURNED_COURTESY_BLACK, ADJOURNED_COURTESY, DRAW_REPITITION, ABORTED_COURTESY, \
+    ADJOURNED_COURTESY_BLACK, ADJOURNED_COURTESY, DRAW_REPETITION, ABORTED_COURTESY, \
     DRAW_50MOVES, ADJOURNED_LOST_CONNECTION_WHITE, ABORTED_EARLY, ABORTED_DISCONNECTION, \
     CANCELLED, PRACTICE_GOAL_REACHED, DRAW_KINGSINEIGHTROW
 
@@ -40,7 +40,7 @@ reprResult_long = {
 reprReason_long = {
     DRAW_INSUFFICIENT:
     _("Because neither player has sufficient material to mate"),
-    DRAW_REPITITION:
+    DRAW_REPETITION:
     _("Because the same position was repeated three times in a row"),
     DRAW_50MOVES: _("Because the last 50 moves brought nothing new"),
     DRAW_CALLFLAG: _("Because both players ran out of time"),
