@@ -27,7 +27,7 @@ __desc__ = _(
 __about__ = _("Official PyChess panel.")
 
 
-class Advisor(object):
+class Advisor:
     def __init__(self, store, name, mode):
         """ The tree store's columns are:
             (Board, Move, pv)           Indicate the suggested move
@@ -123,13 +123,15 @@ class OpeningAdvisor(Advisor):
             goodness = min(float(weight * len(openings)), 1.0)
             weight = "%0.1f%%" % (100 * weight)
 
-            opening = get_eco(b.move(Move(move)).board.hash)
+            opening = get_eco(b.move(Move(move)).board.hash, exactPosition=conf.get('book_exact_match'))
             if opening is None:
                 eco = ""
 #                self.opening_names.append("")
             else:
-                eco = "%s - %s %s" % (opening[0], opening[1], opening[2])
+                eco = "%s - %s%s%s" % (opening[0], opening[1], ', ' if opening[2] != '' else '', opening[2])
 #                self.opening_names.append("%s %s" % (opening[1], opening[2]))
+                if opening[3] == int(False):
+                    eco = '(...) %s' % eco.strip()
 
             self.store.append(parent, [(b, Move(move), None), (
                 weight, 1, goodness), 0, False, eco, False, False])
@@ -436,7 +438,7 @@ class EndgameAdvisor(Advisor):
             self.boardcontrol.play_or_add_move(board, move)
 
 
-class Sidepanel(object):
+class Sidepanel:
     def load(self, gmwidg):
         self.gmwidg = gmwidg
         self.boardcontrol = gmwidg.board
