@@ -5,6 +5,7 @@ import stat
 
 from gi.repository import Gtk
 
+from pychess.compat import create_task
 from pychess.ic import TimeSeal
 from pychess.Savers import pgn
 from pychess.System import conf
@@ -30,7 +31,7 @@ class ExternalsDialog():
         self.window.add(vbox)
         uistuff.keepWindowSize("externalsdialog", self.window, (320, 240), uistuff.POSITION_CENTER)
 
-        label = Gtk.Label(_("Some of PyChess features needs your permission to download external programs"))
+        label = Gtk.Label(_("Some PyChess features require further permission in order to download external components"))
         vbox.pack_start(label, True, True, 0)
 
         box = Gtk.Box()
@@ -106,6 +107,6 @@ class ExternalsDialog():
                     dest = shutil.move(filename, os.path.join(altpath, TimeSeal.timestamp))
                     os.chmod(dest, stat.S_IEXEC | stat.S_IREAD | stat.S_IWRITE)
                     TimeSeal.timestamp_path = dest
-        asyncio.async(coro())
+        create_task(coro())
 
         self.window.emit("delete-event", None)
